@@ -396,10 +396,12 @@ class ToolchainESP32Arduino_1_0_0(ToolChainBase):
         install_path = self.install_path(base)
         exec = self.exec_path(install_path)
         full_command = f"{exec} {command}"
+        if verbose:
+            print(f"+ Build and Flash with command: {full_command}")
         # print(f"DIR: {dirpath}")
         # print(f"EXECUTING: {full_command}")
         # self._invoke_unbuffered(full_command)
-        self._exec(full_command)
+        self._exec(full_command, verbose)
         return True
 
 
